financial_commitment_reports

package
v0.0.79 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 15, 2025 License: MIT Imports: 12 Imported by: 1

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Client

type Client struct {
	// contains filtered or unexported fields
}

Client for financial commitment reports API

func (*Client) CreateFinancialCommitmentReport added in v0.0.48

CreateFinancialCommitmentReport Create a FinancialCommitmentReport.

func (*Client) DeleteFinancialCommitmentReport

DeleteFinancialCommitmentReport Delete a FinancialCommitmentReport.

func (*Client) GetFinancialCommitmentReport

func (a *Client) GetFinancialCommitmentReport(params *GetFinancialCommitmentReportParams, authInfo runtime.ClientAuthInfoWriter, opts ...ClientOption) (*GetFinancialCommitmentReportOK, error)

GetFinancialCommitmentReport Return a FinancialCommitmentReport.

func (*Client) GetFinancialCommitmentReports

func (a *Client) GetFinancialCommitmentReports(params *GetFinancialCommitmentReportsParams, authInfo runtime.ClientAuthInfoWriter, opts ...ClientOption) (*GetFinancialCommitmentReportsOK, error)

GetFinancialCommitmentReports Return all FinancialCommitmentReports.

func (*Client) SetTransport

func (a *Client) SetTransport(transport runtime.ClientTransport)

SetTransport changes the transport on the client

func (*Client) UpdateFinancialCommitmentReport added in v0.0.48

func (a *Client) UpdateFinancialCommitmentReport(params *UpdateFinancialCommitmentReportParams, authInfo runtime.ClientAuthInfoWriter, opts ...ClientOption) (*UpdateFinancialCommitmentReportOK, error)

UpdateFinancialCommitmentReport Update a FinancialCommitmentReport.

type ClientOption

type ClientOption func(*runtime.ClientOperation)

ClientOption may be used to customize the behavior of Client methods.

type ClientService

type ClientService interface {
	CreateFinancialCommitmentReport(params *CreateFinancialCommitmentReportParams, authInfo runtime.ClientAuthInfoWriter, opts ...ClientOption) (*CreateFinancialCommitmentReportCreated, error)

	DeleteFinancialCommitmentReport(params *DeleteFinancialCommitmentReportParams, authInfo runtime.ClientAuthInfoWriter, opts ...ClientOption) (*DeleteFinancialCommitmentReportNoContent, error)

	GetFinancialCommitmentReport(params *GetFinancialCommitmentReportParams, authInfo runtime.ClientAuthInfoWriter, opts ...ClientOption) (*GetFinancialCommitmentReportOK, error)

	GetFinancialCommitmentReports(params *GetFinancialCommitmentReportsParams, authInfo runtime.ClientAuthInfoWriter, opts ...ClientOption) (*GetFinancialCommitmentReportsOK, error)

	UpdateFinancialCommitmentReport(params *UpdateFinancialCommitmentReportParams, authInfo runtime.ClientAuthInfoWriter, opts ...ClientOption) (*UpdateFinancialCommitmentReportOK, error)

	SetTransport(transport runtime.ClientTransport)
}

ClientService is the interface for Client methods

func New

func New(transport runtime.ClientTransport, formats strfmt.Registry) ClientService

New creates a new financial commitment reports API client.

func NewClientWithBasicAuth added in v0.0.33

func NewClientWithBasicAuth(host, basePath, scheme, user, password string) ClientService

New creates a new financial commitment reports API client with basic auth credentials. It takes the following parameters: - host: http host (github.com). - basePath: any base path for the API client ("/v1", "/v3"). - scheme: http scheme ("http", "https"). - user: user for basic authentication header. - password: password for basic authentication header.

func NewClientWithBearerToken added in v0.0.33

func NewClientWithBearerToken(host, basePath, scheme, bearerToken string) ClientService

New creates a new financial commitment reports API client with a bearer token for authentication. It takes the following parameters: - host: http host (github.com). - basePath: any base path for the API client ("/v1", "/v3"). - scheme: http scheme ("http", "https"). - bearerToken: bearer token for Bearer authentication header.

type CreateFinancialCommitmentReportBadRequest added in v0.0.48

type CreateFinancialCommitmentReportBadRequest struct {
	Payload *models.Errors
}

CreateFinancialCommitmentReportBadRequest describes a response with status code 400, with default header values.

BadRequest

func NewCreateFinancialCommitmentReportBadRequest added in v0.0.48

func NewCreateFinancialCommitmentReportBadRequest() *CreateFinancialCommitmentReportBadRequest

NewCreateFinancialCommitmentReportBadRequest creates a CreateFinancialCommitmentReportBadRequest with default headers values

func (*CreateFinancialCommitmentReportBadRequest) Code added in v0.0.48

Code gets the status code for the create financial commitment report bad request response

func (*CreateFinancialCommitmentReportBadRequest) Error added in v0.0.48

func (*CreateFinancialCommitmentReportBadRequest) GetPayload added in v0.0.48

func (*CreateFinancialCommitmentReportBadRequest) IsClientError added in v0.0.48

IsClientError returns true when this create financial commitment report bad request response has a 4xx status code

func (*CreateFinancialCommitmentReportBadRequest) IsCode added in v0.0.48

IsCode returns true when this create financial commitment report bad request response a status code equal to that given

func (*CreateFinancialCommitmentReportBadRequest) IsRedirect added in v0.0.48

IsRedirect returns true when this create financial commitment report bad request response has a 3xx status code

func (*CreateFinancialCommitmentReportBadRequest) IsServerError added in v0.0.48

IsServerError returns true when this create financial commitment report bad request response has a 5xx status code

func (*CreateFinancialCommitmentReportBadRequest) IsSuccess added in v0.0.48

IsSuccess returns true when this create financial commitment report bad request response has a 2xx status code

func (*CreateFinancialCommitmentReportBadRequest) String added in v0.0.48

type CreateFinancialCommitmentReportCreated added in v0.0.48

type CreateFinancialCommitmentReportCreated struct {
	Payload *models.FinancialCommitmentReport
}

CreateFinancialCommitmentReportCreated describes a response with status code 201, with default header values.

CreateFinancialCommitmentReportCreated create financial commitment report created

func NewCreateFinancialCommitmentReportCreated added in v0.0.48

func NewCreateFinancialCommitmentReportCreated() *CreateFinancialCommitmentReportCreated

NewCreateFinancialCommitmentReportCreated creates a CreateFinancialCommitmentReportCreated with default headers values

func (*CreateFinancialCommitmentReportCreated) Code added in v0.0.48

Code gets the status code for the create financial commitment report created response

func (*CreateFinancialCommitmentReportCreated) Error added in v0.0.48

func (*CreateFinancialCommitmentReportCreated) GetPayload added in v0.0.48

func (*CreateFinancialCommitmentReportCreated) IsClientError added in v0.0.48

func (o *CreateFinancialCommitmentReportCreated) IsClientError() bool

IsClientError returns true when this create financial commitment report created response has a 4xx status code

func (*CreateFinancialCommitmentReportCreated) IsCode added in v0.0.48

IsCode returns true when this create financial commitment report created response a status code equal to that given

func (*CreateFinancialCommitmentReportCreated) IsRedirect added in v0.0.48

IsRedirect returns true when this create financial commitment report created response has a 3xx status code

func (*CreateFinancialCommitmentReportCreated) IsServerError added in v0.0.48

func (o *CreateFinancialCommitmentReportCreated) IsServerError() bool

IsServerError returns true when this create financial commitment report created response has a 5xx status code

func (*CreateFinancialCommitmentReportCreated) IsSuccess added in v0.0.48

IsSuccess returns true when this create financial commitment report created response has a 2xx status code

func (*CreateFinancialCommitmentReportCreated) String added in v0.0.48

type CreateFinancialCommitmentReportParams added in v0.0.48

type CreateFinancialCommitmentReportParams struct {

	// CreateFinancialCommitmentReport.
	CreateFinancialCommitmentReport *models.CreateFinancialCommitmentReport

	Context    context.Context
	HTTPClient *http.Client
	// contains filtered or unexported fields
}

CreateFinancialCommitmentReportParams contains all the parameters to send to the API endpoint

for the create financial commitment report operation.

Typically these are written to a http.Request.

func NewCreateFinancialCommitmentReportParams added in v0.0.48

func NewCreateFinancialCommitmentReportParams() *CreateFinancialCommitmentReportParams

NewCreateFinancialCommitmentReportParams creates a new CreateFinancialCommitmentReportParams object, with the default timeout for this client.

Default values are not hydrated, since defaults are normally applied by the API server side.

To enforce default values in parameter, use SetDefaults or WithDefaults.

func NewCreateFinancialCommitmentReportParamsWithContext added in v0.0.48

func NewCreateFinancialCommitmentReportParamsWithContext(ctx context.Context) *CreateFinancialCommitmentReportParams

NewCreateFinancialCommitmentReportParamsWithContext creates a new CreateFinancialCommitmentReportParams object with the ability to set a context for a request.

func NewCreateFinancialCommitmentReportParamsWithHTTPClient added in v0.0.48

func NewCreateFinancialCommitmentReportParamsWithHTTPClient(client *http.Client) *CreateFinancialCommitmentReportParams

NewCreateFinancialCommitmentReportParamsWithHTTPClient creates a new CreateFinancialCommitmentReportParams object with the ability to set a custom HTTPClient for a request.

func NewCreateFinancialCommitmentReportParamsWithTimeout added in v0.0.48

func NewCreateFinancialCommitmentReportParamsWithTimeout(timeout time.Duration) *CreateFinancialCommitmentReportParams

NewCreateFinancialCommitmentReportParamsWithTimeout creates a new CreateFinancialCommitmentReportParams object with the ability to set a timeout on a request.

func (*CreateFinancialCommitmentReportParams) SetContext added in v0.0.48

SetContext adds the context to the create financial commitment report params

func (*CreateFinancialCommitmentReportParams) SetCreateFinancialCommitmentReport added in v0.0.48

func (o *CreateFinancialCommitmentReportParams) SetCreateFinancialCommitmentReport(createFinancialCommitmentReport *models.CreateFinancialCommitmentReport)

SetCreateFinancialCommitmentReport adds the createFinancialCommitmentReport to the create financial commitment report params

func (*CreateFinancialCommitmentReportParams) SetDefaults added in v0.0.48

func (o *CreateFinancialCommitmentReportParams) SetDefaults()

SetDefaults hydrates default values in the create financial commitment report params (not the query body).

All values with no default are reset to their zero value.

func (*CreateFinancialCommitmentReportParams) SetHTTPClient added in v0.0.48

func (o *CreateFinancialCommitmentReportParams) SetHTTPClient(client *http.Client)

SetHTTPClient adds the HTTPClient to the create financial commitment report params

func (*CreateFinancialCommitmentReportParams) SetTimeout added in v0.0.48

func (o *CreateFinancialCommitmentReportParams) SetTimeout(timeout time.Duration)

SetTimeout adds the timeout to the create financial commitment report params

func (*CreateFinancialCommitmentReportParams) WithContext added in v0.0.48

WithContext adds the context to the create financial commitment report params

func (*CreateFinancialCommitmentReportParams) WithCreateFinancialCommitmentReport added in v0.0.48

func (o *CreateFinancialCommitmentReportParams) WithCreateFinancialCommitmentReport(createFinancialCommitmentReport *models.CreateFinancialCommitmentReport) *CreateFinancialCommitmentReportParams

WithCreateFinancialCommitmentReport adds the createFinancialCommitmentReport to the create financial commitment report params

func (*CreateFinancialCommitmentReportParams) WithDefaults added in v0.0.48

WithDefaults hydrates default values in the create financial commitment report params (not the query body).

All values with no default are reset to their zero value.

func (*CreateFinancialCommitmentReportParams) WithHTTPClient added in v0.0.48

WithHTTPClient adds the HTTPClient to the create financial commitment report params

func (*CreateFinancialCommitmentReportParams) WithTimeout added in v0.0.48

WithTimeout adds the timeout to the create financial commitment report params

func (*CreateFinancialCommitmentReportParams) WriteToRequest added in v0.0.48

WriteToRequest writes these params to a swagger request

type CreateFinancialCommitmentReportReader added in v0.0.48

type CreateFinancialCommitmentReportReader struct {
	// contains filtered or unexported fields
}

CreateFinancialCommitmentReportReader is a Reader for the CreateFinancialCommitmentReport structure.

func (*CreateFinancialCommitmentReportReader) ReadResponse added in v0.0.48

func (o *CreateFinancialCommitmentReportReader) ReadResponse(response runtime.ClientResponse, consumer runtime.Consumer) (interface{}, error)

ReadResponse reads a server response into the received o.

type CreateFinancialCommitmentReportUnprocessableEntity added in v0.0.48

type CreateFinancialCommitmentReportUnprocessableEntity struct {
	Payload *models.Errors
}

CreateFinancialCommitmentReportUnprocessableEntity describes a response with status code 422, with default header values.

UnprocessableEntity

func NewCreateFinancialCommitmentReportUnprocessableEntity added in v0.0.48

func NewCreateFinancialCommitmentReportUnprocessableEntity() *CreateFinancialCommitmentReportUnprocessableEntity

NewCreateFinancialCommitmentReportUnprocessableEntity creates a CreateFinancialCommitmentReportUnprocessableEntity with default headers values

func (*CreateFinancialCommitmentReportUnprocessableEntity) Code added in v0.0.48

Code gets the status code for the create financial commitment report unprocessable entity response

func (*CreateFinancialCommitmentReportUnprocessableEntity) Error added in v0.0.48

func (*CreateFinancialCommitmentReportUnprocessableEntity) GetPayload added in v0.0.48

func (*CreateFinancialCommitmentReportUnprocessableEntity) IsClientError added in v0.0.48

IsClientError returns true when this create financial commitment report unprocessable entity response has a 4xx status code

func (*CreateFinancialCommitmentReportUnprocessableEntity) IsCode added in v0.0.48

IsCode returns true when this create financial commitment report unprocessable entity response a status code equal to that given

func (*CreateFinancialCommitmentReportUnprocessableEntity) IsRedirect added in v0.0.48

IsRedirect returns true when this create financial commitment report unprocessable entity response has a 3xx status code

func (*CreateFinancialCommitmentReportUnprocessableEntity) IsServerError added in v0.0.48

IsServerError returns true when this create financial commitment report unprocessable entity response has a 5xx status code

func (*CreateFinancialCommitmentReportUnprocessableEntity) IsSuccess added in v0.0.48

IsSuccess returns true when this create financial commitment report unprocessable entity response has a 2xx status code

func (*CreateFinancialCommitmentReportUnprocessableEntity) String added in v0.0.48

type DeleteFinancialCommitmentReportNoContent

type DeleteFinancialCommitmentReportNoContent struct {
	Payload *models.FinancialCommitmentReport
}

DeleteFinancialCommitmentReportNoContent describes a response with status code 204, with default header values.

DeleteFinancialCommitmentReportNoContent delete financial commitment report no content

func NewDeleteFinancialCommitmentReportNoContent

func NewDeleteFinancialCommitmentReportNoContent() *DeleteFinancialCommitmentReportNoContent

NewDeleteFinancialCommitmentReportNoContent creates a DeleteFinancialCommitmentReportNoContent with default headers values

func (*DeleteFinancialCommitmentReportNoContent) Code

Code gets the status code for the delete financial commitment report no content response

func (*DeleteFinancialCommitmentReportNoContent) Error

func (*DeleteFinancialCommitmentReportNoContent) GetPayload

func (*DeleteFinancialCommitmentReportNoContent) IsClientError

IsClientError returns true when this delete financial commitment report no content response has a 4xx status code

func (*DeleteFinancialCommitmentReportNoContent) IsCode

IsCode returns true when this delete financial commitment report no content response a status code equal to that given

func (*DeleteFinancialCommitmentReportNoContent) IsRedirect

IsRedirect returns true when this delete financial commitment report no content response has a 3xx status code

func (*DeleteFinancialCommitmentReportNoContent) IsServerError

IsServerError returns true when this delete financial commitment report no content response has a 5xx status code

func (*DeleteFinancialCommitmentReportNoContent) IsSuccess

IsSuccess returns true when this delete financial commitment report no content response has a 2xx status code

func (*DeleteFinancialCommitmentReportNoContent) String

type DeleteFinancialCommitmentReportNotFound

type DeleteFinancialCommitmentReportNotFound struct {
	Payload *models.Errors
}

DeleteFinancialCommitmentReportNotFound describes a response with status code 404, with default header values.

NotFound

func NewDeleteFinancialCommitmentReportNotFound

func NewDeleteFinancialCommitmentReportNotFound() *DeleteFinancialCommitmentReportNotFound

NewDeleteFinancialCommitmentReportNotFound creates a DeleteFinancialCommitmentReportNotFound with default headers values

func (*DeleteFinancialCommitmentReportNotFound) Code

Code gets the status code for the delete financial commitment report not found response

func (*DeleteFinancialCommitmentReportNotFound) Error

func (*DeleteFinancialCommitmentReportNotFound) GetPayload

func (*DeleteFinancialCommitmentReportNotFound) IsClientError

func (o *DeleteFinancialCommitmentReportNotFound) IsClientError() bool

IsClientError returns true when this delete financial commitment report not found response has a 4xx status code

func (*DeleteFinancialCommitmentReportNotFound) IsCode

IsCode returns true when this delete financial commitment report not found response a status code equal to that given

func (*DeleteFinancialCommitmentReportNotFound) IsRedirect

IsRedirect returns true when this delete financial commitment report not found response has a 3xx status code

func (*DeleteFinancialCommitmentReportNotFound) IsServerError

func (o *DeleteFinancialCommitmentReportNotFound) IsServerError() bool

IsServerError returns true when this delete financial commitment report not found response has a 5xx status code

func (*DeleteFinancialCommitmentReportNotFound) IsSuccess

IsSuccess returns true when this delete financial commitment report not found response has a 2xx status code

func (*DeleteFinancialCommitmentReportNotFound) String

type DeleteFinancialCommitmentReportParams

type DeleteFinancialCommitmentReportParams struct {

	// FinancialCommitmentReportToken.
	FinancialCommitmentReportToken string

	Context    context.Context
	HTTPClient *http.Client
	// contains filtered or unexported fields
}

DeleteFinancialCommitmentReportParams contains all the parameters to send to the API endpoint

for the delete financial commitment report operation.

Typically these are written to a http.Request.

func NewDeleteFinancialCommitmentReportParams

func NewDeleteFinancialCommitmentReportParams() *DeleteFinancialCommitmentReportParams

NewDeleteFinancialCommitmentReportParams creates a new DeleteFinancialCommitmentReportParams object, with the default timeout for this client.

Default values are not hydrated, since defaults are normally applied by the API server side.

To enforce default values in parameter, use SetDefaults or WithDefaults.

func NewDeleteFinancialCommitmentReportParamsWithContext

func NewDeleteFinancialCommitmentReportParamsWithContext(ctx context.Context) *DeleteFinancialCommitmentReportParams

NewDeleteFinancialCommitmentReportParamsWithContext creates a new DeleteFinancialCommitmentReportParams object with the ability to set a context for a request.

func NewDeleteFinancialCommitmentReportParamsWithHTTPClient

func NewDeleteFinancialCommitmentReportParamsWithHTTPClient(client *http.Client) *DeleteFinancialCommitmentReportParams

NewDeleteFinancialCommitmentReportParamsWithHTTPClient creates a new DeleteFinancialCommitmentReportParams object with the ability to set a custom HTTPClient for a request.

func NewDeleteFinancialCommitmentReportParamsWithTimeout

func NewDeleteFinancialCommitmentReportParamsWithTimeout(timeout time.Duration) *DeleteFinancialCommitmentReportParams

NewDeleteFinancialCommitmentReportParamsWithTimeout creates a new DeleteFinancialCommitmentReportParams object with the ability to set a timeout on a request.

func (*DeleteFinancialCommitmentReportParams) SetContext

SetContext adds the context to the delete financial commitment report params

func (*DeleteFinancialCommitmentReportParams) SetDefaults

func (o *DeleteFinancialCommitmentReportParams) SetDefaults()

SetDefaults hydrates default values in the delete financial commitment report params (not the query body).

All values with no default are reset to their zero value.

func (*DeleteFinancialCommitmentReportParams) SetFinancialCommitmentReportToken

func (o *DeleteFinancialCommitmentReportParams) SetFinancialCommitmentReportToken(financialCommitmentReportToken string)

SetFinancialCommitmentReportToken adds the financialCommitmentReportToken to the delete financial commitment report params

func (*DeleteFinancialCommitmentReportParams) SetHTTPClient

func (o *DeleteFinancialCommitmentReportParams) SetHTTPClient(client *http.Client)

SetHTTPClient adds the HTTPClient to the delete financial commitment report params

func (*DeleteFinancialCommitmentReportParams) SetTimeout

func (o *DeleteFinancialCommitmentReportParams) SetTimeout(timeout time.Duration)

SetTimeout adds the timeout to the delete financial commitment report params

func (*DeleteFinancialCommitmentReportParams) WithContext

WithContext adds the context to the delete financial commitment report params

func (*DeleteFinancialCommitmentReportParams) WithDefaults

WithDefaults hydrates default values in the delete financial commitment report params (not the query body).

All values with no default are reset to their zero value.

func (*DeleteFinancialCommitmentReportParams) WithFinancialCommitmentReportToken

func (o *DeleteFinancialCommitmentReportParams) WithFinancialCommitmentReportToken(financialCommitmentReportToken string) *DeleteFinancialCommitmentReportParams

WithFinancialCommitmentReportToken adds the financialCommitmentReportToken to the delete financial commitment report params

func (*DeleteFinancialCommitmentReportParams) WithHTTPClient

WithHTTPClient adds the HTTPClient to the delete financial commitment report params

func (*DeleteFinancialCommitmentReportParams) WithTimeout

WithTimeout adds the timeout to the delete financial commitment report params

func (*DeleteFinancialCommitmentReportParams) WriteToRequest

WriteToRequest writes these params to a swagger request

type DeleteFinancialCommitmentReportReader

type DeleteFinancialCommitmentReportReader struct {
	// contains filtered or unexported fields
}

DeleteFinancialCommitmentReportReader is a Reader for the DeleteFinancialCommitmentReport structure.

func (*DeleteFinancialCommitmentReportReader) ReadResponse

func (o *DeleteFinancialCommitmentReportReader) ReadResponse(response runtime.ClientResponse, consumer runtime.Consumer) (interface{}, error)

ReadResponse reads a server response into the received o.

type GetFinancialCommitmentReportNotFound

type GetFinancialCommitmentReportNotFound struct {
	Payload *models.Errors
}

GetFinancialCommitmentReportNotFound describes a response with status code 404, with default header values.

NotFound

func NewGetFinancialCommitmentReportNotFound

func NewGetFinancialCommitmentReportNotFound() *GetFinancialCommitmentReportNotFound

NewGetFinancialCommitmentReportNotFound creates a GetFinancialCommitmentReportNotFound with default headers values

func (*GetFinancialCommitmentReportNotFound) Code

Code gets the status code for the get financial commitment report not found response

func (*GetFinancialCommitmentReportNotFound) Error

func (*GetFinancialCommitmentReportNotFound) GetPayload

func (*GetFinancialCommitmentReportNotFound) IsClientError

func (o *GetFinancialCommitmentReportNotFound) IsClientError() bool

IsClientError returns true when this get financial commitment report not found response has a 4xx status code

func (*GetFinancialCommitmentReportNotFound) IsCode

IsCode returns true when this get financial commitment report not found response a status code equal to that given

func (*GetFinancialCommitmentReportNotFound) IsRedirect

IsRedirect returns true when this get financial commitment report not found response has a 3xx status code

func (*GetFinancialCommitmentReportNotFound) IsServerError

func (o *GetFinancialCommitmentReportNotFound) IsServerError() bool

IsServerError returns true when this get financial commitment report not found response has a 5xx status code

func (*GetFinancialCommitmentReportNotFound) IsSuccess

IsSuccess returns true when this get financial commitment report not found response has a 2xx status code

func (*GetFinancialCommitmentReportNotFound) String

type GetFinancialCommitmentReportOK

type GetFinancialCommitmentReportOK struct {
	Payload *models.FinancialCommitmentReport
}

GetFinancialCommitmentReportOK describes a response with status code 200, with default header values.

GetFinancialCommitmentReportOK get financial commitment report o k

func NewGetFinancialCommitmentReportOK

func NewGetFinancialCommitmentReportOK() *GetFinancialCommitmentReportOK

NewGetFinancialCommitmentReportOK creates a GetFinancialCommitmentReportOK with default headers values

func (*GetFinancialCommitmentReportOK) Code

Code gets the status code for the get financial commitment report o k response

func (*GetFinancialCommitmentReportOK) Error

func (*GetFinancialCommitmentReportOK) GetPayload

func (*GetFinancialCommitmentReportOK) IsClientError

func (o *GetFinancialCommitmentReportOK) IsClientError() bool

IsClientError returns true when this get financial commitment report o k response has a 4xx status code

func (*GetFinancialCommitmentReportOK) IsCode

func (o *GetFinancialCommitmentReportOK) IsCode(code int) bool

IsCode returns true when this get financial commitment report o k response a status code equal to that given

func (*GetFinancialCommitmentReportOK) IsRedirect

func (o *GetFinancialCommitmentReportOK) IsRedirect() bool

IsRedirect returns true when this get financial commitment report o k response has a 3xx status code

func (*GetFinancialCommitmentReportOK) IsServerError

func (o *GetFinancialCommitmentReportOK) IsServerError() bool

IsServerError returns true when this get financial commitment report o k response has a 5xx status code

func (*GetFinancialCommitmentReportOK) IsSuccess

func (o *GetFinancialCommitmentReportOK) IsSuccess() bool

IsSuccess returns true when this get financial commitment report o k response has a 2xx status code

func (*GetFinancialCommitmentReportOK) String

type GetFinancialCommitmentReportParams

type GetFinancialCommitmentReportParams struct {

	// FinancialCommitmentReportToken.
	FinancialCommitmentReportToken string

	Context    context.Context
	HTTPClient *http.Client
	// contains filtered or unexported fields
}

GetFinancialCommitmentReportParams contains all the parameters to send to the API endpoint

for the get financial commitment report operation.

Typically these are written to a http.Request.

func NewGetFinancialCommitmentReportParams

func NewGetFinancialCommitmentReportParams() *GetFinancialCommitmentReportParams

NewGetFinancialCommitmentReportParams creates a new GetFinancialCommitmentReportParams object, with the default timeout for this client.

Default values are not hydrated, since defaults are normally applied by the API server side.

To enforce default values in parameter, use SetDefaults or WithDefaults.

func NewGetFinancialCommitmentReportParamsWithContext

func NewGetFinancialCommitmentReportParamsWithContext(ctx context.Context) *GetFinancialCommitmentReportParams

NewGetFinancialCommitmentReportParamsWithContext creates a new GetFinancialCommitmentReportParams object with the ability to set a context for a request.

func NewGetFinancialCommitmentReportParamsWithHTTPClient

func NewGetFinancialCommitmentReportParamsWithHTTPClient(client *http.Client) *GetFinancialCommitmentReportParams

NewGetFinancialCommitmentReportParamsWithHTTPClient creates a new GetFinancialCommitmentReportParams object with the ability to set a custom HTTPClient for a request.

func NewGetFinancialCommitmentReportParamsWithTimeout

func NewGetFinancialCommitmentReportParamsWithTimeout(timeout time.Duration) *GetFinancialCommitmentReportParams

NewGetFinancialCommitmentReportParamsWithTimeout creates a new GetFinancialCommitmentReportParams object with the ability to set a timeout on a request.

func (*GetFinancialCommitmentReportParams) SetContext

SetContext adds the context to the get financial commitment report params

func (*GetFinancialCommitmentReportParams) SetDefaults

func (o *GetFinancialCommitmentReportParams) SetDefaults()

SetDefaults hydrates default values in the get financial commitment report params (not the query body).

All values with no default are reset to their zero value.

func (*GetFinancialCommitmentReportParams) SetFinancialCommitmentReportToken

func (o *GetFinancialCommitmentReportParams) SetFinancialCommitmentReportToken(financialCommitmentReportToken string)

SetFinancialCommitmentReportToken adds the financialCommitmentReportToken to the get financial commitment report params

func (*GetFinancialCommitmentReportParams) SetHTTPClient

func (o *GetFinancialCommitmentReportParams) SetHTTPClient(client *http.Client)

SetHTTPClient adds the HTTPClient to the get financial commitment report params

func (*GetFinancialCommitmentReportParams) SetTimeout

func (o *GetFinancialCommitmentReportParams) SetTimeout(timeout time.Duration)

SetTimeout adds the timeout to the get financial commitment report params

func (*GetFinancialCommitmentReportParams) WithContext

WithContext adds the context to the get financial commitment report params

func (*GetFinancialCommitmentReportParams) WithDefaults

WithDefaults hydrates default values in the get financial commitment report params (not the query body).

All values with no default are reset to their zero value.

func (*GetFinancialCommitmentReportParams) WithFinancialCommitmentReportToken

func (o *GetFinancialCommitmentReportParams) WithFinancialCommitmentReportToken(financialCommitmentReportToken string) *GetFinancialCommitmentReportParams

WithFinancialCommitmentReportToken adds the financialCommitmentReportToken to the get financial commitment report params

func (*GetFinancialCommitmentReportParams) WithHTTPClient

WithHTTPClient adds the HTTPClient to the get financial commitment report params

func (*GetFinancialCommitmentReportParams) WithTimeout

WithTimeout adds the timeout to the get financial commitment report params

func (*GetFinancialCommitmentReportParams) WriteToRequest

WriteToRequest writes these params to a swagger request

type GetFinancialCommitmentReportReader

type GetFinancialCommitmentReportReader struct {
	// contains filtered or unexported fields
}

GetFinancialCommitmentReportReader is a Reader for the GetFinancialCommitmentReport structure.

func (*GetFinancialCommitmentReportReader) ReadResponse

func (o *GetFinancialCommitmentReportReader) ReadResponse(response runtime.ClientResponse, consumer runtime.Consumer) (interface{}, error)

ReadResponse reads a server response into the received o.

type GetFinancialCommitmentReportsOK

type GetFinancialCommitmentReportsOK struct {
	Payload *models.FinancialCommitmentReports
}

GetFinancialCommitmentReportsOK describes a response with status code 200, with default header values.

GetFinancialCommitmentReportsOK get financial commitment reports o k

func NewGetFinancialCommitmentReportsOK

func NewGetFinancialCommitmentReportsOK() *GetFinancialCommitmentReportsOK

NewGetFinancialCommitmentReportsOK creates a GetFinancialCommitmentReportsOK with default headers values

func (*GetFinancialCommitmentReportsOK) Code

Code gets the status code for the get financial commitment reports o k response

func (*GetFinancialCommitmentReportsOK) Error

func (*GetFinancialCommitmentReportsOK) GetPayload

func (*GetFinancialCommitmentReportsOK) IsClientError

func (o *GetFinancialCommitmentReportsOK) IsClientError() bool

IsClientError returns true when this get financial commitment reports o k response has a 4xx status code

func (*GetFinancialCommitmentReportsOK) IsCode

func (o *GetFinancialCommitmentReportsOK) IsCode(code int) bool

IsCode returns true when this get financial commitment reports o k response a status code equal to that given

func (*GetFinancialCommitmentReportsOK) IsRedirect

func (o *GetFinancialCommitmentReportsOK) IsRedirect() bool

IsRedirect returns true when this get financial commitment reports o k response has a 3xx status code

func (*GetFinancialCommitmentReportsOK) IsServerError

func (o *GetFinancialCommitmentReportsOK) IsServerError() bool

IsServerError returns true when this get financial commitment reports o k response has a 5xx status code

func (*GetFinancialCommitmentReportsOK) IsSuccess

func (o *GetFinancialCommitmentReportsOK) IsSuccess() bool

IsSuccess returns true when this get financial commitment reports o k response has a 2xx status code

func (*GetFinancialCommitmentReportsOK) String

type GetFinancialCommitmentReportsParams

type GetFinancialCommitmentReportsParams struct {

	/* Limit.

	   The amount of results to return. The maximum is 1000.

	   Format: int32
	*/
	Limit *int32

	/* Page.

	   The page of results to return.

	   Format: int32
	*/
	Page *int32

	Context    context.Context
	HTTPClient *http.Client
	// contains filtered or unexported fields
}

GetFinancialCommitmentReportsParams contains all the parameters to send to the API endpoint

for the get financial commitment reports operation.

Typically these are written to a http.Request.

func NewGetFinancialCommitmentReportsParams

func NewGetFinancialCommitmentReportsParams() *GetFinancialCommitmentReportsParams

NewGetFinancialCommitmentReportsParams creates a new GetFinancialCommitmentReportsParams object, with the default timeout for this client.

Default values are not hydrated, since defaults are normally applied by the API server side.

To enforce default values in parameter, use SetDefaults or WithDefaults.

func NewGetFinancialCommitmentReportsParamsWithContext

func NewGetFinancialCommitmentReportsParamsWithContext(ctx context.Context) *GetFinancialCommitmentReportsParams

NewGetFinancialCommitmentReportsParamsWithContext creates a new GetFinancialCommitmentReportsParams object with the ability to set a context for a request.

func NewGetFinancialCommitmentReportsParamsWithHTTPClient

func NewGetFinancialCommitmentReportsParamsWithHTTPClient(client *http.Client) *GetFinancialCommitmentReportsParams

NewGetFinancialCommitmentReportsParamsWithHTTPClient creates a new GetFinancialCommitmentReportsParams object with the ability to set a custom HTTPClient for a request.

func NewGetFinancialCommitmentReportsParamsWithTimeout

func NewGetFinancialCommitmentReportsParamsWithTimeout(timeout time.Duration) *GetFinancialCommitmentReportsParams

NewGetFinancialCommitmentReportsParamsWithTimeout creates a new GetFinancialCommitmentReportsParams object with the ability to set a timeout on a request.

func (*GetFinancialCommitmentReportsParams) SetContext

SetContext adds the context to the get financial commitment reports params

func (*GetFinancialCommitmentReportsParams) SetDefaults

func (o *GetFinancialCommitmentReportsParams) SetDefaults()

SetDefaults hydrates default values in the get financial commitment reports params (not the query body).

All values with no default are reset to their zero value.

func (*GetFinancialCommitmentReportsParams) SetHTTPClient

func (o *GetFinancialCommitmentReportsParams) SetHTTPClient(client *http.Client)

SetHTTPClient adds the HTTPClient to the get financial commitment reports params

func (*GetFinancialCommitmentReportsParams) SetLimit

func (o *GetFinancialCommitmentReportsParams) SetLimit(limit *int32)

SetLimit adds the limit to the get financial commitment reports params

func (*GetFinancialCommitmentReportsParams) SetPage

func (o *GetFinancialCommitmentReportsParams) SetPage(page *int32)

SetPage adds the page to the get financial commitment reports params

func (*GetFinancialCommitmentReportsParams) SetTimeout

func (o *GetFinancialCommitmentReportsParams) SetTimeout(timeout time.Duration)

SetTimeout adds the timeout to the get financial commitment reports params

func (*GetFinancialCommitmentReportsParams) WithContext

WithContext adds the context to the get financial commitment reports params

func (*GetFinancialCommitmentReportsParams) WithDefaults

WithDefaults hydrates default values in the get financial commitment reports params (not the query body).

All values with no default are reset to their zero value.

func (*GetFinancialCommitmentReportsParams) WithHTTPClient

WithHTTPClient adds the HTTPClient to the get financial commitment reports params

func (*GetFinancialCommitmentReportsParams) WithLimit

WithLimit adds the limit to the get financial commitment reports params

func (*GetFinancialCommitmentReportsParams) WithPage

WithPage adds the page to the get financial commitment reports params

func (*GetFinancialCommitmentReportsParams) WithTimeout

WithTimeout adds the timeout to the get financial commitment reports params

func (*GetFinancialCommitmentReportsParams) WriteToRequest

WriteToRequest writes these params to a swagger request

type GetFinancialCommitmentReportsReader

type GetFinancialCommitmentReportsReader struct {
	// contains filtered or unexported fields
}

GetFinancialCommitmentReportsReader is a Reader for the GetFinancialCommitmentReports structure.

func (*GetFinancialCommitmentReportsReader) ReadResponse

func (o *GetFinancialCommitmentReportsReader) ReadResponse(response runtime.ClientResponse, consumer runtime.Consumer) (interface{}, error)

ReadResponse reads a server response into the received o.

type UpdateFinancialCommitmentReportBadRequest added in v0.0.48

type UpdateFinancialCommitmentReportBadRequest struct {
	Payload *models.Errors
}

UpdateFinancialCommitmentReportBadRequest describes a response with status code 400, with default header values.

BadRequest

func NewUpdateFinancialCommitmentReportBadRequest added in v0.0.48

func NewUpdateFinancialCommitmentReportBadRequest() *UpdateFinancialCommitmentReportBadRequest

NewUpdateFinancialCommitmentReportBadRequest creates a UpdateFinancialCommitmentReportBadRequest with default headers values

func (*UpdateFinancialCommitmentReportBadRequest) Code added in v0.0.48

Code gets the status code for the update financial commitment report bad request response

func (*UpdateFinancialCommitmentReportBadRequest) Error added in v0.0.48

func (*UpdateFinancialCommitmentReportBadRequest) GetPayload added in v0.0.48

func (*UpdateFinancialCommitmentReportBadRequest) IsClientError added in v0.0.48

IsClientError returns true when this update financial commitment report bad request response has a 4xx status code

func (*UpdateFinancialCommitmentReportBadRequest) IsCode added in v0.0.48

IsCode returns true when this update financial commitment report bad request response a status code equal to that given

func (*UpdateFinancialCommitmentReportBadRequest) IsRedirect added in v0.0.48

IsRedirect returns true when this update financial commitment report bad request response has a 3xx status code

func (*UpdateFinancialCommitmentReportBadRequest) IsServerError added in v0.0.48

IsServerError returns true when this update financial commitment report bad request response has a 5xx status code

func (*UpdateFinancialCommitmentReportBadRequest) IsSuccess added in v0.0.48

IsSuccess returns true when this update financial commitment report bad request response has a 2xx status code

func (*UpdateFinancialCommitmentReportBadRequest) String added in v0.0.48

type UpdateFinancialCommitmentReportOK added in v0.0.48

type UpdateFinancialCommitmentReportOK struct {
	Payload *models.FinancialCommitmentReport
}

UpdateFinancialCommitmentReportOK describes a response with status code 200, with default header values.

UpdateFinancialCommitmentReportOK update financial commitment report o k

func NewUpdateFinancialCommitmentReportOK added in v0.0.48

func NewUpdateFinancialCommitmentReportOK() *UpdateFinancialCommitmentReportOK

NewUpdateFinancialCommitmentReportOK creates a UpdateFinancialCommitmentReportOK with default headers values

func (*UpdateFinancialCommitmentReportOK) Code added in v0.0.48

Code gets the status code for the update financial commitment report o k response

func (*UpdateFinancialCommitmentReportOK) Error added in v0.0.48

func (*UpdateFinancialCommitmentReportOK) GetPayload added in v0.0.48

func (*UpdateFinancialCommitmentReportOK) IsClientError added in v0.0.48

func (o *UpdateFinancialCommitmentReportOK) IsClientError() bool

IsClientError returns true when this update financial commitment report o k response has a 4xx status code

func (*UpdateFinancialCommitmentReportOK) IsCode added in v0.0.48

func (o *UpdateFinancialCommitmentReportOK) IsCode(code int) bool

IsCode returns true when this update financial commitment report o k response a status code equal to that given

func (*UpdateFinancialCommitmentReportOK) IsRedirect added in v0.0.48

func (o *UpdateFinancialCommitmentReportOK) IsRedirect() bool

IsRedirect returns true when this update financial commitment report o k response has a 3xx status code

func (*UpdateFinancialCommitmentReportOK) IsServerError added in v0.0.48

func (o *UpdateFinancialCommitmentReportOK) IsServerError() bool

IsServerError returns true when this update financial commitment report o k response has a 5xx status code

func (*UpdateFinancialCommitmentReportOK) IsSuccess added in v0.0.48

func (o *UpdateFinancialCommitmentReportOK) IsSuccess() bool

IsSuccess returns true when this update financial commitment report o k response has a 2xx status code

func (*UpdateFinancialCommitmentReportOK) String added in v0.0.48

type UpdateFinancialCommitmentReportParams added in v0.0.48

type UpdateFinancialCommitmentReportParams struct {

	// FinancialCommitmentReportToken.
	FinancialCommitmentReportToken string

	// UpdateFinancialCommitmentReport.
	UpdateFinancialCommitmentReport *models.UpdateFinancialCommitmentReport

	Context    context.Context
	HTTPClient *http.Client
	// contains filtered or unexported fields
}

UpdateFinancialCommitmentReportParams contains all the parameters to send to the API endpoint

for the update financial commitment report operation.

Typically these are written to a http.Request.

func NewUpdateFinancialCommitmentReportParams added in v0.0.48

func NewUpdateFinancialCommitmentReportParams() *UpdateFinancialCommitmentReportParams

NewUpdateFinancialCommitmentReportParams creates a new UpdateFinancialCommitmentReportParams object, with the default timeout for this client.

Default values are not hydrated, since defaults are normally applied by the API server side.

To enforce default values in parameter, use SetDefaults or WithDefaults.

func NewUpdateFinancialCommitmentReportParamsWithContext added in v0.0.48

func NewUpdateFinancialCommitmentReportParamsWithContext(ctx context.Context) *UpdateFinancialCommitmentReportParams

NewUpdateFinancialCommitmentReportParamsWithContext creates a new UpdateFinancialCommitmentReportParams object with the ability to set a context for a request.

func NewUpdateFinancialCommitmentReportParamsWithHTTPClient added in v0.0.48

func NewUpdateFinancialCommitmentReportParamsWithHTTPClient(client *http.Client) *UpdateFinancialCommitmentReportParams

NewUpdateFinancialCommitmentReportParamsWithHTTPClient creates a new UpdateFinancialCommitmentReportParams object with the ability to set a custom HTTPClient for a request.

func NewUpdateFinancialCommitmentReportParamsWithTimeout added in v0.0.48

func NewUpdateFinancialCommitmentReportParamsWithTimeout(timeout time.Duration) *UpdateFinancialCommitmentReportParams

NewUpdateFinancialCommitmentReportParamsWithTimeout creates a new UpdateFinancialCommitmentReportParams object with the ability to set a timeout on a request.

func (*UpdateFinancialCommitmentReportParams) SetContext added in v0.0.48

SetContext adds the context to the update financial commitment report params

func (*UpdateFinancialCommitmentReportParams) SetDefaults added in v0.0.48

func (o *UpdateFinancialCommitmentReportParams) SetDefaults()

SetDefaults hydrates default values in the update financial commitment report params (not the query body).

All values with no default are reset to their zero value.

func (*UpdateFinancialCommitmentReportParams) SetFinancialCommitmentReportToken added in v0.0.48

func (o *UpdateFinancialCommitmentReportParams) SetFinancialCommitmentReportToken(financialCommitmentReportToken string)

SetFinancialCommitmentReportToken adds the financialCommitmentReportToken to the update financial commitment report params

func (*UpdateFinancialCommitmentReportParams) SetHTTPClient added in v0.0.48

func (o *UpdateFinancialCommitmentReportParams) SetHTTPClient(client *http.Client)

SetHTTPClient adds the HTTPClient to the update financial commitment report params

func (*UpdateFinancialCommitmentReportParams) SetTimeout added in v0.0.48

func (o *UpdateFinancialCommitmentReportParams) SetTimeout(timeout time.Duration)

SetTimeout adds the timeout to the update financial commitment report params

func (*UpdateFinancialCommitmentReportParams) SetUpdateFinancialCommitmentReport added in v0.0.48

func (o *UpdateFinancialCommitmentReportParams) SetUpdateFinancialCommitmentReport(updateFinancialCommitmentReport *models.UpdateFinancialCommitmentReport)

SetUpdateFinancialCommitmentReport adds the updateFinancialCommitmentReport to the update financial commitment report params

func (*UpdateFinancialCommitmentReportParams) WithContext added in v0.0.48

WithContext adds the context to the update financial commitment report params

func (*UpdateFinancialCommitmentReportParams) WithDefaults added in v0.0.48

WithDefaults hydrates default values in the update financial commitment report params (not the query body).

All values with no default are reset to their zero value.

func (*UpdateFinancialCommitmentReportParams) WithFinancialCommitmentReportToken added in v0.0.48

func (o *UpdateFinancialCommitmentReportParams) WithFinancialCommitmentReportToken(financialCommitmentReportToken string) *UpdateFinancialCommitmentReportParams

WithFinancialCommitmentReportToken adds the financialCommitmentReportToken to the update financial commitment report params

func (*UpdateFinancialCommitmentReportParams) WithHTTPClient added in v0.0.48

WithHTTPClient adds the HTTPClient to the update financial commitment report params

func (*UpdateFinancialCommitmentReportParams) WithTimeout added in v0.0.48

WithTimeout adds the timeout to the update financial commitment report params

func (*UpdateFinancialCommitmentReportParams) WithUpdateFinancialCommitmentReport added in v0.0.48

func (o *UpdateFinancialCommitmentReportParams) WithUpdateFinancialCommitmentReport(updateFinancialCommitmentReport *models.UpdateFinancialCommitmentReport) *UpdateFinancialCommitmentReportParams

WithUpdateFinancialCommitmentReport adds the updateFinancialCommitmentReport to the update financial commitment report params

func (*UpdateFinancialCommitmentReportParams) WriteToRequest added in v0.0.48

WriteToRequest writes these params to a swagger request

type UpdateFinancialCommitmentReportReader added in v0.0.48

type UpdateFinancialCommitmentReportReader struct {
	// contains filtered or unexported fields
}

UpdateFinancialCommitmentReportReader is a Reader for the UpdateFinancialCommitmentReport structure.

func (*UpdateFinancialCommitmentReportReader) ReadResponse added in v0.0.48

func (o *UpdateFinancialCommitmentReportReader) ReadResponse(response runtime.ClientResponse, consumer runtime.Consumer) (interface{}, error)

ReadResponse reads a server response into the received o.

type UpdateFinancialCommitmentReportUnprocessableEntity added in v0.0.48

type UpdateFinancialCommitmentReportUnprocessableEntity struct {
	Payload *models.Errors
}

UpdateFinancialCommitmentReportUnprocessableEntity describes a response with status code 422, with default header values.

UnprocessableEntity

func NewUpdateFinancialCommitmentReportUnprocessableEntity added in v0.0.48

func NewUpdateFinancialCommitmentReportUnprocessableEntity() *UpdateFinancialCommitmentReportUnprocessableEntity

NewUpdateFinancialCommitmentReportUnprocessableEntity creates a UpdateFinancialCommitmentReportUnprocessableEntity with default headers values

func (*UpdateFinancialCommitmentReportUnprocessableEntity) Code added in v0.0.48

Code gets the status code for the update financial commitment report unprocessable entity response

func (*UpdateFinancialCommitmentReportUnprocessableEntity) Error added in v0.0.48

func (*UpdateFinancialCommitmentReportUnprocessableEntity) GetPayload added in v0.0.48

func (*UpdateFinancialCommitmentReportUnprocessableEntity) IsClientError added in v0.0.48

IsClientError returns true when this update financial commitment report unprocessable entity response has a 4xx status code

func (*UpdateFinancialCommitmentReportUnprocessableEntity) IsCode added in v0.0.48

IsCode returns true when this update financial commitment report unprocessable entity response a status code equal to that given

func (*UpdateFinancialCommitmentReportUnprocessableEntity) IsRedirect added in v0.0.48

IsRedirect returns true when this update financial commitment report unprocessable entity response has a 3xx status code

func (*UpdateFinancialCommitmentReportUnprocessableEntity) IsServerError added in v0.0.48

IsServerError returns true when this update financial commitment report unprocessable entity response has a 5xx status code

func (*UpdateFinancialCommitmentReportUnprocessableEntity) IsSuccess added in v0.0.48

IsSuccess returns true when this update financial commitment report unprocessable entity response has a 2xx status code

func (*UpdateFinancialCommitmentReportUnprocessableEntity) String added in v0.0.48

Jump to