kubernetes_efficiency_reports

package
v0.0.79 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 15, 2025 License: MIT Imports: 12 Imported by: 1

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Client

type Client struct {
	// contains filtered or unexported fields
}

Client for kubernetes efficiency reports API

func (*Client) CreateKubernetesEfficiencyReport added in v0.0.41

CreateKubernetesEfficiencyReport Create a KubernetesEfficiencyReport.

func (*Client) DeleteKubernetesEfficiencyReport

DeleteKubernetesEfficiencyReport Delete a KubernetesEfficiencyReport.

func (*Client) GetKubernetesEfficiencyReport

func (a *Client) GetKubernetesEfficiencyReport(params *GetKubernetesEfficiencyReportParams, authInfo runtime.ClientAuthInfoWriter, opts ...ClientOption) (*GetKubernetesEfficiencyReportOK, error)

GetKubernetesEfficiencyReport Return a KubernetesEfficiencyReport.

func (*Client) GetKubernetesEfficiencyReports

func (a *Client) GetKubernetesEfficiencyReports(params *GetKubernetesEfficiencyReportsParams, authInfo runtime.ClientAuthInfoWriter, opts ...ClientOption) (*GetKubernetesEfficiencyReportsOK, error)

GetKubernetesEfficiencyReports Return all KubernetesEfficiencyReports.

func (*Client) SetTransport

func (a *Client) SetTransport(transport runtime.ClientTransport)

SetTransport changes the transport on the client

func (*Client) UpdateKubernetesEfficiencyReport added in v0.0.41

func (a *Client) UpdateKubernetesEfficiencyReport(params *UpdateKubernetesEfficiencyReportParams, authInfo runtime.ClientAuthInfoWriter, opts ...ClientOption) (*UpdateKubernetesEfficiencyReportOK, error)

UpdateKubernetesEfficiencyReport Update a KubernetesEfficiencyReport.

type ClientOption

type ClientOption func(*runtime.ClientOperation)

ClientOption may be used to customize the behavior of Client methods.

type ClientService

type ClientService interface {
	CreateKubernetesEfficiencyReport(params *CreateKubernetesEfficiencyReportParams, authInfo runtime.ClientAuthInfoWriter, opts ...ClientOption) (*CreateKubernetesEfficiencyReportCreated, error)

	DeleteKubernetesEfficiencyReport(params *DeleteKubernetesEfficiencyReportParams, authInfo runtime.ClientAuthInfoWriter, opts ...ClientOption) (*DeleteKubernetesEfficiencyReportNoContent, error)

	GetKubernetesEfficiencyReport(params *GetKubernetesEfficiencyReportParams, authInfo runtime.ClientAuthInfoWriter, opts ...ClientOption) (*GetKubernetesEfficiencyReportOK, error)

	GetKubernetesEfficiencyReports(params *GetKubernetesEfficiencyReportsParams, authInfo runtime.ClientAuthInfoWriter, opts ...ClientOption) (*GetKubernetesEfficiencyReportsOK, error)

	UpdateKubernetesEfficiencyReport(params *UpdateKubernetesEfficiencyReportParams, authInfo runtime.ClientAuthInfoWriter, opts ...ClientOption) (*UpdateKubernetesEfficiencyReportOK, error)

	SetTransport(transport runtime.ClientTransport)
}

ClientService is the interface for Client methods

func New

func New(transport runtime.ClientTransport, formats strfmt.Registry) ClientService

New creates a new kubernetes efficiency reports API client.

func NewClientWithBasicAuth added in v0.0.33

func NewClientWithBasicAuth(host, basePath, scheme, user, password string) ClientService

New creates a new kubernetes efficiency reports API client with basic auth credentials. It takes the following parameters: - host: http host (github.com). - basePath: any base path for the API client ("/v1", "/v3"). - scheme: http scheme ("http", "https"). - user: user for basic authentication header. - password: password for basic authentication header.

func NewClientWithBearerToken added in v0.0.33

func NewClientWithBearerToken(host, basePath, scheme, bearerToken string) ClientService

New creates a new kubernetes efficiency reports API client with a bearer token for authentication. It takes the following parameters: - host: http host (github.com). - basePath: any base path for the API client ("/v1", "/v3"). - scheme: http scheme ("http", "https"). - bearerToken: bearer token for Bearer authentication header.

type CreateKubernetesEfficiencyReportBadRequest added in v0.0.41

type CreateKubernetesEfficiencyReportBadRequest struct {
	Payload *models.Errors
}

CreateKubernetesEfficiencyReportBadRequest describes a response with status code 400, with default header values.

BadRequest

func NewCreateKubernetesEfficiencyReportBadRequest added in v0.0.41

func NewCreateKubernetesEfficiencyReportBadRequest() *CreateKubernetesEfficiencyReportBadRequest

NewCreateKubernetesEfficiencyReportBadRequest creates a CreateKubernetesEfficiencyReportBadRequest with default headers values

func (*CreateKubernetesEfficiencyReportBadRequest) Code added in v0.0.41

Code gets the status code for the create kubernetes efficiency report bad request response

func (*CreateKubernetesEfficiencyReportBadRequest) Error added in v0.0.41

func (*CreateKubernetesEfficiencyReportBadRequest) GetPayload added in v0.0.41

func (*CreateKubernetesEfficiencyReportBadRequest) IsClientError added in v0.0.41

IsClientError returns true when this create kubernetes efficiency report bad request response has a 4xx status code

func (*CreateKubernetesEfficiencyReportBadRequest) IsCode added in v0.0.41

IsCode returns true when this create kubernetes efficiency report bad request response a status code equal to that given

func (*CreateKubernetesEfficiencyReportBadRequest) IsRedirect added in v0.0.41

IsRedirect returns true when this create kubernetes efficiency report bad request response has a 3xx status code

func (*CreateKubernetesEfficiencyReportBadRequest) IsServerError added in v0.0.41

IsServerError returns true when this create kubernetes efficiency report bad request response has a 5xx status code

func (*CreateKubernetesEfficiencyReportBadRequest) IsSuccess added in v0.0.41

IsSuccess returns true when this create kubernetes efficiency report bad request response has a 2xx status code

func (*CreateKubernetesEfficiencyReportBadRequest) String added in v0.0.41

type CreateKubernetesEfficiencyReportCreated added in v0.0.41

type CreateKubernetesEfficiencyReportCreated struct {
	Payload *models.KubernetesEfficiencyReport
}

CreateKubernetesEfficiencyReportCreated describes a response with status code 201, with default header values.

CreateKubernetesEfficiencyReportCreated create kubernetes efficiency report created

func NewCreateKubernetesEfficiencyReportCreated added in v0.0.41

func NewCreateKubernetesEfficiencyReportCreated() *CreateKubernetesEfficiencyReportCreated

NewCreateKubernetesEfficiencyReportCreated creates a CreateKubernetesEfficiencyReportCreated with default headers values

func (*CreateKubernetesEfficiencyReportCreated) Code added in v0.0.41

Code gets the status code for the create kubernetes efficiency report created response

func (*CreateKubernetesEfficiencyReportCreated) Error added in v0.0.41

func (*CreateKubernetesEfficiencyReportCreated) GetPayload added in v0.0.41

func (*CreateKubernetesEfficiencyReportCreated) IsClientError added in v0.0.41

func (o *CreateKubernetesEfficiencyReportCreated) IsClientError() bool

IsClientError returns true when this create kubernetes efficiency report created response has a 4xx status code

func (*CreateKubernetesEfficiencyReportCreated) IsCode added in v0.0.41

IsCode returns true when this create kubernetes efficiency report created response a status code equal to that given

func (*CreateKubernetesEfficiencyReportCreated) IsRedirect added in v0.0.41

IsRedirect returns true when this create kubernetes efficiency report created response has a 3xx status code

func (*CreateKubernetesEfficiencyReportCreated) IsServerError added in v0.0.41

func (o *CreateKubernetesEfficiencyReportCreated) IsServerError() bool

IsServerError returns true when this create kubernetes efficiency report created response has a 5xx status code

func (*CreateKubernetesEfficiencyReportCreated) IsSuccess added in v0.0.41

IsSuccess returns true when this create kubernetes efficiency report created response has a 2xx status code

func (*CreateKubernetesEfficiencyReportCreated) String added in v0.0.41

type CreateKubernetesEfficiencyReportParams added in v0.0.41

type CreateKubernetesEfficiencyReportParams struct {

	// CreateKubernetesEfficiencyReport.
	CreateKubernetesEfficiencyReport *models.CreateKubernetesEfficiencyReport

	Context    context.Context
	HTTPClient *http.Client
	// contains filtered or unexported fields
}

CreateKubernetesEfficiencyReportParams contains all the parameters to send to the API endpoint

for the create kubernetes efficiency report operation.

Typically these are written to a http.Request.

func NewCreateKubernetesEfficiencyReportParams added in v0.0.41

func NewCreateKubernetesEfficiencyReportParams() *CreateKubernetesEfficiencyReportParams

NewCreateKubernetesEfficiencyReportParams creates a new CreateKubernetesEfficiencyReportParams object, with the default timeout for this client.

Default values are not hydrated, since defaults are normally applied by the API server side.

To enforce default values in parameter, use SetDefaults or WithDefaults.

func NewCreateKubernetesEfficiencyReportParamsWithContext added in v0.0.41

func NewCreateKubernetesEfficiencyReportParamsWithContext(ctx context.Context) *CreateKubernetesEfficiencyReportParams

NewCreateKubernetesEfficiencyReportParamsWithContext creates a new CreateKubernetesEfficiencyReportParams object with the ability to set a context for a request.

func NewCreateKubernetesEfficiencyReportParamsWithHTTPClient added in v0.0.41

func NewCreateKubernetesEfficiencyReportParamsWithHTTPClient(client *http.Client) *CreateKubernetesEfficiencyReportParams

NewCreateKubernetesEfficiencyReportParamsWithHTTPClient creates a new CreateKubernetesEfficiencyReportParams object with the ability to set a custom HTTPClient for a request.

func NewCreateKubernetesEfficiencyReportParamsWithTimeout added in v0.0.41

func NewCreateKubernetesEfficiencyReportParamsWithTimeout(timeout time.Duration) *CreateKubernetesEfficiencyReportParams

NewCreateKubernetesEfficiencyReportParamsWithTimeout creates a new CreateKubernetesEfficiencyReportParams object with the ability to set a timeout on a request.

func (*CreateKubernetesEfficiencyReportParams) SetContext added in v0.0.41

SetContext adds the context to the create kubernetes efficiency report params

func (*CreateKubernetesEfficiencyReportParams) SetCreateKubernetesEfficiencyReport added in v0.0.41

func (o *CreateKubernetesEfficiencyReportParams) SetCreateKubernetesEfficiencyReport(createKubernetesEfficiencyReport *models.CreateKubernetesEfficiencyReport)

SetCreateKubernetesEfficiencyReport adds the createKubernetesEfficiencyReport to the create kubernetes efficiency report params

func (*CreateKubernetesEfficiencyReportParams) SetDefaults added in v0.0.41

func (o *CreateKubernetesEfficiencyReportParams) SetDefaults()

SetDefaults hydrates default values in the create kubernetes efficiency report params (not the query body).

All values with no default are reset to their zero value.

func (*CreateKubernetesEfficiencyReportParams) SetHTTPClient added in v0.0.41

func (o *CreateKubernetesEfficiencyReportParams) SetHTTPClient(client *http.Client)

SetHTTPClient adds the HTTPClient to the create kubernetes efficiency report params

func (*CreateKubernetesEfficiencyReportParams) SetTimeout added in v0.0.41

func (o *CreateKubernetesEfficiencyReportParams) SetTimeout(timeout time.Duration)

SetTimeout adds the timeout to the create kubernetes efficiency report params

func (*CreateKubernetesEfficiencyReportParams) WithContext added in v0.0.41

WithContext adds the context to the create kubernetes efficiency report params

func (*CreateKubernetesEfficiencyReportParams) WithCreateKubernetesEfficiencyReport added in v0.0.41

func (o *CreateKubernetesEfficiencyReportParams) WithCreateKubernetesEfficiencyReport(createKubernetesEfficiencyReport *models.CreateKubernetesEfficiencyReport) *CreateKubernetesEfficiencyReportParams

WithCreateKubernetesEfficiencyReport adds the createKubernetesEfficiencyReport to the create kubernetes efficiency report params

func (*CreateKubernetesEfficiencyReportParams) WithDefaults added in v0.0.41

WithDefaults hydrates default values in the create kubernetes efficiency report params (not the query body).

All values with no default are reset to their zero value.

func (*CreateKubernetesEfficiencyReportParams) WithHTTPClient added in v0.0.41

WithHTTPClient adds the HTTPClient to the create kubernetes efficiency report params

func (*CreateKubernetesEfficiencyReportParams) WithTimeout added in v0.0.41

WithTimeout adds the timeout to the create kubernetes efficiency report params

func (*CreateKubernetesEfficiencyReportParams) WriteToRequest added in v0.0.41

WriteToRequest writes these params to a swagger request

type CreateKubernetesEfficiencyReportReader added in v0.0.41

type CreateKubernetesEfficiencyReportReader struct {
	// contains filtered or unexported fields
}

CreateKubernetesEfficiencyReportReader is a Reader for the CreateKubernetesEfficiencyReport structure.

func (*CreateKubernetesEfficiencyReportReader) ReadResponse added in v0.0.41

func (o *CreateKubernetesEfficiencyReportReader) ReadResponse(response runtime.ClientResponse, consumer runtime.Consumer) (interface{}, error)

ReadResponse reads a server response into the received o.

type CreateKubernetesEfficiencyReportUnprocessableEntity added in v0.0.41

type CreateKubernetesEfficiencyReportUnprocessableEntity struct {
	Payload *models.Errors
}

CreateKubernetesEfficiencyReportUnprocessableEntity describes a response with status code 422, with default header values.

UnprocessableEntity

func NewCreateKubernetesEfficiencyReportUnprocessableEntity added in v0.0.41

func NewCreateKubernetesEfficiencyReportUnprocessableEntity() *CreateKubernetesEfficiencyReportUnprocessableEntity

NewCreateKubernetesEfficiencyReportUnprocessableEntity creates a CreateKubernetesEfficiencyReportUnprocessableEntity with default headers values

func (*CreateKubernetesEfficiencyReportUnprocessableEntity) Code added in v0.0.41

Code gets the status code for the create kubernetes efficiency report unprocessable entity response

func (*CreateKubernetesEfficiencyReportUnprocessableEntity) Error added in v0.0.41

func (*CreateKubernetesEfficiencyReportUnprocessableEntity) GetPayload added in v0.0.41

func (*CreateKubernetesEfficiencyReportUnprocessableEntity) IsClientError added in v0.0.41

IsClientError returns true when this create kubernetes efficiency report unprocessable entity response has a 4xx status code

func (*CreateKubernetesEfficiencyReportUnprocessableEntity) IsCode added in v0.0.41

IsCode returns true when this create kubernetes efficiency report unprocessable entity response a status code equal to that given

func (*CreateKubernetesEfficiencyReportUnprocessableEntity) IsRedirect added in v0.0.41

IsRedirect returns true when this create kubernetes efficiency report unprocessable entity response has a 3xx status code

func (*CreateKubernetesEfficiencyReportUnprocessableEntity) IsServerError added in v0.0.41

IsServerError returns true when this create kubernetes efficiency report unprocessable entity response has a 5xx status code

func (*CreateKubernetesEfficiencyReportUnprocessableEntity) IsSuccess added in v0.0.41

IsSuccess returns true when this create kubernetes efficiency report unprocessable entity response has a 2xx status code

func (*CreateKubernetesEfficiencyReportUnprocessableEntity) String added in v0.0.41

type DeleteKubernetesEfficiencyReportNoContent

type DeleteKubernetesEfficiencyReportNoContent struct {
	Payload *models.KubernetesEfficiencyReport
}

DeleteKubernetesEfficiencyReportNoContent describes a response with status code 204, with default header values.

DeleteKubernetesEfficiencyReportNoContent delete kubernetes efficiency report no content

func NewDeleteKubernetesEfficiencyReportNoContent

func NewDeleteKubernetesEfficiencyReportNoContent() *DeleteKubernetesEfficiencyReportNoContent

NewDeleteKubernetesEfficiencyReportNoContent creates a DeleteKubernetesEfficiencyReportNoContent with default headers values

func (*DeleteKubernetesEfficiencyReportNoContent) Code

Code gets the status code for the delete kubernetes efficiency report no content response

func (*DeleteKubernetesEfficiencyReportNoContent) Error

func (*DeleteKubernetesEfficiencyReportNoContent) GetPayload

func (*DeleteKubernetesEfficiencyReportNoContent) IsClientError

IsClientError returns true when this delete kubernetes efficiency report no content response has a 4xx status code

func (*DeleteKubernetesEfficiencyReportNoContent) IsCode

IsCode returns true when this delete kubernetes efficiency report no content response a status code equal to that given

func (*DeleteKubernetesEfficiencyReportNoContent) IsRedirect

IsRedirect returns true when this delete kubernetes efficiency report no content response has a 3xx status code

func (*DeleteKubernetesEfficiencyReportNoContent) IsServerError

IsServerError returns true when this delete kubernetes efficiency report no content response has a 5xx status code

func (*DeleteKubernetesEfficiencyReportNoContent) IsSuccess

IsSuccess returns true when this delete kubernetes efficiency report no content response has a 2xx status code

func (*DeleteKubernetesEfficiencyReportNoContent) String

type DeleteKubernetesEfficiencyReportNotFound

type DeleteKubernetesEfficiencyReportNotFound struct {
	Payload *models.Errors
}

DeleteKubernetesEfficiencyReportNotFound describes a response with status code 404, with default header values.

NotFound

func NewDeleteKubernetesEfficiencyReportNotFound

func NewDeleteKubernetesEfficiencyReportNotFound() *DeleteKubernetesEfficiencyReportNotFound

NewDeleteKubernetesEfficiencyReportNotFound creates a DeleteKubernetesEfficiencyReportNotFound with default headers values

func (*DeleteKubernetesEfficiencyReportNotFound) Code

Code gets the status code for the delete kubernetes efficiency report not found response

func (*DeleteKubernetesEfficiencyReportNotFound) Error

func (*DeleteKubernetesEfficiencyReportNotFound) GetPayload

func (*DeleteKubernetesEfficiencyReportNotFound) IsClientError

IsClientError returns true when this delete kubernetes efficiency report not found response has a 4xx status code

func (*DeleteKubernetesEfficiencyReportNotFound) IsCode

IsCode returns true when this delete kubernetes efficiency report not found response a status code equal to that given

func (*DeleteKubernetesEfficiencyReportNotFound) IsRedirect

IsRedirect returns true when this delete kubernetes efficiency report not found response has a 3xx status code

func (*DeleteKubernetesEfficiencyReportNotFound) IsServerError

IsServerError returns true when this delete kubernetes efficiency report not found response has a 5xx status code

func (*DeleteKubernetesEfficiencyReportNotFound) IsSuccess

IsSuccess returns true when this delete kubernetes efficiency report not found response has a 2xx status code

func (*DeleteKubernetesEfficiencyReportNotFound) String

type DeleteKubernetesEfficiencyReportParams

type DeleteKubernetesEfficiencyReportParams struct {

	// KubernetesEfficiencyReportToken.
	KubernetesEfficiencyReportToken string

	Context    context.Context
	HTTPClient *http.Client
	// contains filtered or unexported fields
}

DeleteKubernetesEfficiencyReportParams contains all the parameters to send to the API endpoint

for the delete kubernetes efficiency report operation.

Typically these are written to a http.Request.

func NewDeleteKubernetesEfficiencyReportParams

func NewDeleteKubernetesEfficiencyReportParams() *DeleteKubernetesEfficiencyReportParams

NewDeleteKubernetesEfficiencyReportParams creates a new DeleteKubernetesEfficiencyReportParams object, with the default timeout for this client.

Default values are not hydrated, since defaults are normally applied by the API server side.

To enforce default values in parameter, use SetDefaults or WithDefaults.

func NewDeleteKubernetesEfficiencyReportParamsWithContext

func NewDeleteKubernetesEfficiencyReportParamsWithContext(ctx context.Context) *DeleteKubernetesEfficiencyReportParams

NewDeleteKubernetesEfficiencyReportParamsWithContext creates a new DeleteKubernetesEfficiencyReportParams object with the ability to set a context for a request.

func NewDeleteKubernetesEfficiencyReportParamsWithHTTPClient

func NewDeleteKubernetesEfficiencyReportParamsWithHTTPClient(client *http.Client) *DeleteKubernetesEfficiencyReportParams

NewDeleteKubernetesEfficiencyReportParamsWithHTTPClient creates a new DeleteKubernetesEfficiencyReportParams object with the ability to set a custom HTTPClient for a request.

func NewDeleteKubernetesEfficiencyReportParamsWithTimeout

func NewDeleteKubernetesEfficiencyReportParamsWithTimeout(timeout time.Duration) *DeleteKubernetesEfficiencyReportParams

NewDeleteKubernetesEfficiencyReportParamsWithTimeout creates a new DeleteKubernetesEfficiencyReportParams object with the ability to set a timeout on a request.

func (*DeleteKubernetesEfficiencyReportParams) SetContext

SetContext adds the context to the delete kubernetes efficiency report params

func (*DeleteKubernetesEfficiencyReportParams) SetDefaults

func (o *DeleteKubernetesEfficiencyReportParams) SetDefaults()

SetDefaults hydrates default values in the delete kubernetes efficiency report params (not the query body).

All values with no default are reset to their zero value.

func (*DeleteKubernetesEfficiencyReportParams) SetHTTPClient

func (o *DeleteKubernetesEfficiencyReportParams) SetHTTPClient(client *http.Client)

SetHTTPClient adds the HTTPClient to the delete kubernetes efficiency report params

func (*DeleteKubernetesEfficiencyReportParams) SetKubernetesEfficiencyReportToken

func (o *DeleteKubernetesEfficiencyReportParams) SetKubernetesEfficiencyReportToken(kubernetesEfficiencyReportToken string)

SetKubernetesEfficiencyReportToken adds the kubernetesEfficiencyReportToken to the delete kubernetes efficiency report params

func (*DeleteKubernetesEfficiencyReportParams) SetTimeout

func (o *DeleteKubernetesEfficiencyReportParams) SetTimeout(timeout time.Duration)

SetTimeout adds the timeout to the delete kubernetes efficiency report params

func (*DeleteKubernetesEfficiencyReportParams) WithContext

WithContext adds the context to the delete kubernetes efficiency report params

func (*DeleteKubernetesEfficiencyReportParams) WithDefaults

WithDefaults hydrates default values in the delete kubernetes efficiency report params (not the query body).

All values with no default are reset to their zero value.

func (*DeleteKubernetesEfficiencyReportParams) WithHTTPClient

WithHTTPClient adds the HTTPClient to the delete kubernetes efficiency report params

func (*DeleteKubernetesEfficiencyReportParams) WithKubernetesEfficiencyReportToken

func (o *DeleteKubernetesEfficiencyReportParams) WithKubernetesEfficiencyReportToken(kubernetesEfficiencyReportToken string) *DeleteKubernetesEfficiencyReportParams

WithKubernetesEfficiencyReportToken adds the kubernetesEfficiencyReportToken to the delete kubernetes efficiency report params

func (*DeleteKubernetesEfficiencyReportParams) WithTimeout

WithTimeout adds the timeout to the delete kubernetes efficiency report params

func (*DeleteKubernetesEfficiencyReportParams) WriteToRequest

WriteToRequest writes these params to a swagger request

type DeleteKubernetesEfficiencyReportReader

type DeleteKubernetesEfficiencyReportReader struct {
	// contains filtered or unexported fields
}

DeleteKubernetesEfficiencyReportReader is a Reader for the DeleteKubernetesEfficiencyReport structure.

func (*DeleteKubernetesEfficiencyReportReader) ReadResponse

func (o *DeleteKubernetesEfficiencyReportReader) ReadResponse(response runtime.ClientResponse, consumer runtime.Consumer) (interface{}, error)

ReadResponse reads a server response into the received o.

type GetKubernetesEfficiencyReportNotFound

type GetKubernetesEfficiencyReportNotFound struct {
	Payload *models.Errors
}

GetKubernetesEfficiencyReportNotFound describes a response with status code 404, with default header values.

NotFound

func NewGetKubernetesEfficiencyReportNotFound

func NewGetKubernetesEfficiencyReportNotFound() *GetKubernetesEfficiencyReportNotFound

NewGetKubernetesEfficiencyReportNotFound creates a GetKubernetesEfficiencyReportNotFound with default headers values

func (*GetKubernetesEfficiencyReportNotFound) Code

Code gets the status code for the get kubernetes efficiency report not found response

func (*GetKubernetesEfficiencyReportNotFound) Error

func (*GetKubernetesEfficiencyReportNotFound) GetPayload

func (*GetKubernetesEfficiencyReportNotFound) IsClientError

func (o *GetKubernetesEfficiencyReportNotFound) IsClientError() bool

IsClientError returns true when this get kubernetes efficiency report not found response has a 4xx status code

func (*GetKubernetesEfficiencyReportNotFound) IsCode

IsCode returns true when this get kubernetes efficiency report not found response a status code equal to that given

func (*GetKubernetesEfficiencyReportNotFound) IsRedirect

IsRedirect returns true when this get kubernetes efficiency report not found response has a 3xx status code

func (*GetKubernetesEfficiencyReportNotFound) IsServerError

func (o *GetKubernetesEfficiencyReportNotFound) IsServerError() bool

IsServerError returns true when this get kubernetes efficiency report not found response has a 5xx status code

func (*GetKubernetesEfficiencyReportNotFound) IsSuccess

IsSuccess returns true when this get kubernetes efficiency report not found response has a 2xx status code

func (*GetKubernetesEfficiencyReportNotFound) String

type GetKubernetesEfficiencyReportOK

type GetKubernetesEfficiencyReportOK struct {
	Payload *models.KubernetesEfficiencyReport
}

GetKubernetesEfficiencyReportOK describes a response with status code 200, with default header values.

GetKubernetesEfficiencyReportOK get kubernetes efficiency report o k

func NewGetKubernetesEfficiencyReportOK

func NewGetKubernetesEfficiencyReportOK() *GetKubernetesEfficiencyReportOK

NewGetKubernetesEfficiencyReportOK creates a GetKubernetesEfficiencyReportOK with default headers values

func (*GetKubernetesEfficiencyReportOK) Code

Code gets the status code for the get kubernetes efficiency report o k response

func (*GetKubernetesEfficiencyReportOK) Error

func (*GetKubernetesEfficiencyReportOK) GetPayload

func (*GetKubernetesEfficiencyReportOK) IsClientError

func (o *GetKubernetesEfficiencyReportOK) IsClientError() bool

IsClientError returns true when this get kubernetes efficiency report o k response has a 4xx status code

func (*GetKubernetesEfficiencyReportOK) IsCode

func (o *GetKubernetesEfficiencyReportOK) IsCode(code int) bool

IsCode returns true when this get kubernetes efficiency report o k response a status code equal to that given

func (*GetKubernetesEfficiencyReportOK) IsRedirect

func (o *GetKubernetesEfficiencyReportOK) IsRedirect() bool

IsRedirect returns true when this get kubernetes efficiency report o k response has a 3xx status code

func (*GetKubernetesEfficiencyReportOK) IsServerError

func (o *GetKubernetesEfficiencyReportOK) IsServerError() bool

IsServerError returns true when this get kubernetes efficiency report o k response has a 5xx status code

func (*GetKubernetesEfficiencyReportOK) IsSuccess

func (o *GetKubernetesEfficiencyReportOK) IsSuccess() bool

IsSuccess returns true when this get kubernetes efficiency report o k response has a 2xx status code

func (*GetKubernetesEfficiencyReportOK) String

type GetKubernetesEfficiencyReportParams

type GetKubernetesEfficiencyReportParams struct {

	// KubernetesEfficiencyReportToken.
	KubernetesEfficiencyReportToken string

	Context    context.Context
	HTTPClient *http.Client
	// contains filtered or unexported fields
}

GetKubernetesEfficiencyReportParams contains all the parameters to send to the API endpoint

for the get kubernetes efficiency report operation.

Typically these are written to a http.Request.

func NewGetKubernetesEfficiencyReportParams

func NewGetKubernetesEfficiencyReportParams() *GetKubernetesEfficiencyReportParams

NewGetKubernetesEfficiencyReportParams creates a new GetKubernetesEfficiencyReportParams object, with the default timeout for this client.

Default values are not hydrated, since defaults are normally applied by the API server side.

To enforce default values in parameter, use SetDefaults or WithDefaults.

func NewGetKubernetesEfficiencyReportParamsWithContext

func NewGetKubernetesEfficiencyReportParamsWithContext(ctx context.Context) *GetKubernetesEfficiencyReportParams

NewGetKubernetesEfficiencyReportParamsWithContext creates a new GetKubernetesEfficiencyReportParams object with the ability to set a context for a request.

func NewGetKubernetesEfficiencyReportParamsWithHTTPClient

func NewGetKubernetesEfficiencyReportParamsWithHTTPClient(client *http.Client) *GetKubernetesEfficiencyReportParams

NewGetKubernetesEfficiencyReportParamsWithHTTPClient creates a new GetKubernetesEfficiencyReportParams object with the ability to set a custom HTTPClient for a request.

func NewGetKubernetesEfficiencyReportParamsWithTimeout

func NewGetKubernetesEfficiencyReportParamsWithTimeout(timeout time.Duration) *GetKubernetesEfficiencyReportParams

NewGetKubernetesEfficiencyReportParamsWithTimeout creates a new GetKubernetesEfficiencyReportParams object with the ability to set a timeout on a request.

func (*GetKubernetesEfficiencyReportParams) SetContext

SetContext adds the context to the get kubernetes efficiency report params

func (*GetKubernetesEfficiencyReportParams) SetDefaults

func (o *GetKubernetesEfficiencyReportParams) SetDefaults()

SetDefaults hydrates default values in the get kubernetes efficiency report params (not the query body).

All values with no default are reset to their zero value.

func (*GetKubernetesEfficiencyReportParams) SetHTTPClient

func (o *GetKubernetesEfficiencyReportParams) SetHTTPClient(client *http.Client)

SetHTTPClient adds the HTTPClient to the get kubernetes efficiency report params

func (*GetKubernetesEfficiencyReportParams) SetKubernetesEfficiencyReportToken

func (o *GetKubernetesEfficiencyReportParams) SetKubernetesEfficiencyReportToken(kubernetesEfficiencyReportToken string)

SetKubernetesEfficiencyReportToken adds the kubernetesEfficiencyReportToken to the get kubernetes efficiency report params

func (*GetKubernetesEfficiencyReportParams) SetTimeout

func (o *GetKubernetesEfficiencyReportParams) SetTimeout(timeout time.Duration)

SetTimeout adds the timeout to the get kubernetes efficiency report params

func (*GetKubernetesEfficiencyReportParams) WithContext

WithContext adds the context to the get kubernetes efficiency report params

func (*GetKubernetesEfficiencyReportParams) WithDefaults

WithDefaults hydrates default values in the get kubernetes efficiency report params (not the query body).

All values with no default are reset to their zero value.

func (*GetKubernetesEfficiencyReportParams) WithHTTPClient

WithHTTPClient adds the HTTPClient to the get kubernetes efficiency report params

func (*GetKubernetesEfficiencyReportParams) WithKubernetesEfficiencyReportToken

func (o *GetKubernetesEfficiencyReportParams) WithKubernetesEfficiencyReportToken(kubernetesEfficiencyReportToken string) *GetKubernetesEfficiencyReportParams

WithKubernetesEfficiencyReportToken adds the kubernetesEfficiencyReportToken to the get kubernetes efficiency report params

func (*GetKubernetesEfficiencyReportParams) WithTimeout

WithTimeout adds the timeout to the get kubernetes efficiency report params

func (*GetKubernetesEfficiencyReportParams) WriteToRequest

WriteToRequest writes these params to a swagger request

type GetKubernetesEfficiencyReportReader

type GetKubernetesEfficiencyReportReader struct {
	// contains filtered or unexported fields
}

GetKubernetesEfficiencyReportReader is a Reader for the GetKubernetesEfficiencyReport structure.

func (*GetKubernetesEfficiencyReportReader) ReadResponse

func (o *GetKubernetesEfficiencyReportReader) ReadResponse(response runtime.ClientResponse, consumer runtime.Consumer) (interface{}, error)

ReadResponse reads a server response into the received o.

type GetKubernetesEfficiencyReportsOK

type GetKubernetesEfficiencyReportsOK struct {
	Payload *models.KubernetesEfficiencyReports
}

GetKubernetesEfficiencyReportsOK describes a response with status code 200, with default header values.

GetKubernetesEfficiencyReportsOK get kubernetes efficiency reports o k

func NewGetKubernetesEfficiencyReportsOK

func NewGetKubernetesEfficiencyReportsOK() *GetKubernetesEfficiencyReportsOK

NewGetKubernetesEfficiencyReportsOK creates a GetKubernetesEfficiencyReportsOK with default headers values

func (*GetKubernetesEfficiencyReportsOK) Code

Code gets the status code for the get kubernetes efficiency reports o k response

func (*GetKubernetesEfficiencyReportsOK) Error

func (*GetKubernetesEfficiencyReportsOK) GetPayload

func (*GetKubernetesEfficiencyReportsOK) IsClientError

func (o *GetKubernetesEfficiencyReportsOK) IsClientError() bool

IsClientError returns true when this get kubernetes efficiency reports o k response has a 4xx status code

func (*GetKubernetesEfficiencyReportsOK) IsCode

func (o *GetKubernetesEfficiencyReportsOK) IsCode(code int) bool

IsCode returns true when this get kubernetes efficiency reports o k response a status code equal to that given

func (*GetKubernetesEfficiencyReportsOK) IsRedirect

func (o *GetKubernetesEfficiencyReportsOK) IsRedirect() bool

IsRedirect returns true when this get kubernetes efficiency reports o k response has a 3xx status code

func (*GetKubernetesEfficiencyReportsOK) IsServerError

func (o *GetKubernetesEfficiencyReportsOK) IsServerError() bool

IsServerError returns true when this get kubernetes efficiency reports o k response has a 5xx status code

func (*GetKubernetesEfficiencyReportsOK) IsSuccess

func (o *GetKubernetesEfficiencyReportsOK) IsSuccess() bool

IsSuccess returns true when this get kubernetes efficiency reports o k response has a 2xx status code

func (*GetKubernetesEfficiencyReportsOK) String

type GetKubernetesEfficiencyReportsParams

type GetKubernetesEfficiencyReportsParams struct {

	/* Limit.

	   The amount of results to return. The maximum is 1000.

	   Format: int32
	*/
	Limit *int32

	/* Page.

	   The page of results to return.

	   Format: int32
	*/
	Page *int32

	Context    context.Context
	HTTPClient *http.Client
	// contains filtered or unexported fields
}

GetKubernetesEfficiencyReportsParams contains all the parameters to send to the API endpoint

for the get kubernetes efficiency reports operation.

Typically these are written to a http.Request.

func NewGetKubernetesEfficiencyReportsParams

func NewGetKubernetesEfficiencyReportsParams() *GetKubernetesEfficiencyReportsParams

NewGetKubernetesEfficiencyReportsParams creates a new GetKubernetesEfficiencyReportsParams object, with the default timeout for this client.

Default values are not hydrated, since defaults are normally applied by the API server side.

To enforce default values in parameter, use SetDefaults or WithDefaults.

func NewGetKubernetesEfficiencyReportsParamsWithContext

func NewGetKubernetesEfficiencyReportsParamsWithContext(ctx context.Context) *GetKubernetesEfficiencyReportsParams

NewGetKubernetesEfficiencyReportsParamsWithContext creates a new GetKubernetesEfficiencyReportsParams object with the ability to set a context for a request.

func NewGetKubernetesEfficiencyReportsParamsWithHTTPClient

func NewGetKubernetesEfficiencyReportsParamsWithHTTPClient(client *http.Client) *GetKubernetesEfficiencyReportsParams

NewGetKubernetesEfficiencyReportsParamsWithHTTPClient creates a new GetKubernetesEfficiencyReportsParams object with the ability to set a custom HTTPClient for a request.

func NewGetKubernetesEfficiencyReportsParamsWithTimeout

func NewGetKubernetesEfficiencyReportsParamsWithTimeout(timeout time.Duration) *GetKubernetesEfficiencyReportsParams

NewGetKubernetesEfficiencyReportsParamsWithTimeout creates a new GetKubernetesEfficiencyReportsParams object with the ability to set a timeout on a request.

func (*GetKubernetesEfficiencyReportsParams) SetContext

SetContext adds the context to the get kubernetes efficiency reports params

func (*GetKubernetesEfficiencyReportsParams) SetDefaults

func (o *GetKubernetesEfficiencyReportsParams) SetDefaults()

SetDefaults hydrates default values in the get kubernetes efficiency reports params (not the query body).

All values with no default are reset to their zero value.

func (*GetKubernetesEfficiencyReportsParams) SetHTTPClient

func (o *GetKubernetesEfficiencyReportsParams) SetHTTPClient(client *http.Client)

SetHTTPClient adds the HTTPClient to the get kubernetes efficiency reports params

func (*GetKubernetesEfficiencyReportsParams) SetLimit

func (o *GetKubernetesEfficiencyReportsParams) SetLimit(limit *int32)

SetLimit adds the limit to the get kubernetes efficiency reports params

func (*GetKubernetesEfficiencyReportsParams) SetPage

func (o *GetKubernetesEfficiencyReportsParams) SetPage(page *int32)

SetPage adds the page to the get kubernetes efficiency reports params

func (*GetKubernetesEfficiencyReportsParams) SetTimeout

func (o *GetKubernetesEfficiencyReportsParams) SetTimeout(timeout time.Duration)

SetTimeout adds the timeout to the get kubernetes efficiency reports params

func (*GetKubernetesEfficiencyReportsParams) WithContext

WithContext adds the context to the get kubernetes efficiency reports params

func (*GetKubernetesEfficiencyReportsParams) WithDefaults

WithDefaults hydrates default values in the get kubernetes efficiency reports params (not the query body).

All values with no default are reset to their zero value.

func (*GetKubernetesEfficiencyReportsParams) WithHTTPClient

WithHTTPClient adds the HTTPClient to the get kubernetes efficiency reports params

func (*GetKubernetesEfficiencyReportsParams) WithLimit

WithLimit adds the limit to the get kubernetes efficiency reports params

func (*GetKubernetesEfficiencyReportsParams) WithPage

WithPage adds the page to the get kubernetes efficiency reports params

func (*GetKubernetesEfficiencyReportsParams) WithTimeout

WithTimeout adds the timeout to the get kubernetes efficiency reports params

func (*GetKubernetesEfficiencyReportsParams) WriteToRequest

WriteToRequest writes these params to a swagger request

type GetKubernetesEfficiencyReportsReader

type GetKubernetesEfficiencyReportsReader struct {
	// contains filtered or unexported fields
}

GetKubernetesEfficiencyReportsReader is a Reader for the GetKubernetesEfficiencyReports structure.

func (*GetKubernetesEfficiencyReportsReader) ReadResponse

func (o *GetKubernetesEfficiencyReportsReader) ReadResponse(response runtime.ClientResponse, consumer runtime.Consumer) (interface{}, error)

ReadResponse reads a server response into the received o.

type UpdateKubernetesEfficiencyReportBadRequest added in v0.0.41

type UpdateKubernetesEfficiencyReportBadRequest struct {
	Payload *models.Errors
}

UpdateKubernetesEfficiencyReportBadRequest describes a response with status code 400, with default header values.

BadRequest

func NewUpdateKubernetesEfficiencyReportBadRequest added in v0.0.41

func NewUpdateKubernetesEfficiencyReportBadRequest() *UpdateKubernetesEfficiencyReportBadRequest

NewUpdateKubernetesEfficiencyReportBadRequest creates a UpdateKubernetesEfficiencyReportBadRequest with default headers values

func (*UpdateKubernetesEfficiencyReportBadRequest) Code added in v0.0.41

Code gets the status code for the update kubernetes efficiency report bad request response

func (*UpdateKubernetesEfficiencyReportBadRequest) Error added in v0.0.41

func (*UpdateKubernetesEfficiencyReportBadRequest) GetPayload added in v0.0.41

func (*UpdateKubernetesEfficiencyReportBadRequest) IsClientError added in v0.0.41

IsClientError returns true when this update kubernetes efficiency report bad request response has a 4xx status code

func (*UpdateKubernetesEfficiencyReportBadRequest) IsCode added in v0.0.41

IsCode returns true when this update kubernetes efficiency report bad request response a status code equal to that given

func (*UpdateKubernetesEfficiencyReportBadRequest) IsRedirect added in v0.0.41

IsRedirect returns true when this update kubernetes efficiency report bad request response has a 3xx status code

func (*UpdateKubernetesEfficiencyReportBadRequest) IsServerError added in v0.0.41

IsServerError returns true when this update kubernetes efficiency report bad request response has a 5xx status code

func (*UpdateKubernetesEfficiencyReportBadRequest) IsSuccess added in v0.0.41

IsSuccess returns true when this update kubernetes efficiency report bad request response has a 2xx status code

func (*UpdateKubernetesEfficiencyReportBadRequest) String added in v0.0.41

type UpdateKubernetesEfficiencyReportOK added in v0.0.41

type UpdateKubernetesEfficiencyReportOK struct {
	Payload *models.KubernetesEfficiencyReport
}

UpdateKubernetesEfficiencyReportOK describes a response with status code 200, with default header values.

UpdateKubernetesEfficiencyReportOK update kubernetes efficiency report o k

func NewUpdateKubernetesEfficiencyReportOK added in v0.0.41

func NewUpdateKubernetesEfficiencyReportOK() *UpdateKubernetesEfficiencyReportOK

NewUpdateKubernetesEfficiencyReportOK creates a UpdateKubernetesEfficiencyReportOK with default headers values

func (*UpdateKubernetesEfficiencyReportOK) Code added in v0.0.41

Code gets the status code for the update kubernetes efficiency report o k response

func (*UpdateKubernetesEfficiencyReportOK) Error added in v0.0.41

func (*UpdateKubernetesEfficiencyReportOK) GetPayload added in v0.0.41

func (*UpdateKubernetesEfficiencyReportOK) IsClientError added in v0.0.41

func (o *UpdateKubernetesEfficiencyReportOK) IsClientError() bool

IsClientError returns true when this update kubernetes efficiency report o k response has a 4xx status code

func (*UpdateKubernetesEfficiencyReportOK) IsCode added in v0.0.41

IsCode returns true when this update kubernetes efficiency report o k response a status code equal to that given

func (*UpdateKubernetesEfficiencyReportOK) IsRedirect added in v0.0.41

func (o *UpdateKubernetesEfficiencyReportOK) IsRedirect() bool

IsRedirect returns true when this update kubernetes efficiency report o k response has a 3xx status code

func (*UpdateKubernetesEfficiencyReportOK) IsServerError added in v0.0.41

func (o *UpdateKubernetesEfficiencyReportOK) IsServerError() bool

IsServerError returns true when this update kubernetes efficiency report o k response has a 5xx status code

func (*UpdateKubernetesEfficiencyReportOK) IsSuccess added in v0.0.41

IsSuccess returns true when this update kubernetes efficiency report o k response has a 2xx status code

func (*UpdateKubernetesEfficiencyReportOK) String added in v0.0.41

type UpdateKubernetesEfficiencyReportParams added in v0.0.41

type UpdateKubernetesEfficiencyReportParams struct {

	// KubernetesEfficiencyReportToken.
	KubernetesEfficiencyReportToken string

	// UpdateKubernetesEfficiencyReport.
	UpdateKubernetesEfficiencyReport *models.UpdateKubernetesEfficiencyReport

	Context    context.Context
	HTTPClient *http.Client
	// contains filtered or unexported fields
}

UpdateKubernetesEfficiencyReportParams contains all the parameters to send to the API endpoint

for the update kubernetes efficiency report operation.

Typically these are written to a http.Request.

func NewUpdateKubernetesEfficiencyReportParams added in v0.0.41

func NewUpdateKubernetesEfficiencyReportParams() *UpdateKubernetesEfficiencyReportParams

NewUpdateKubernetesEfficiencyReportParams creates a new UpdateKubernetesEfficiencyReportParams object, with the default timeout for this client.

Default values are not hydrated, since defaults are normally applied by the API server side.

To enforce default values in parameter, use SetDefaults or WithDefaults.

func NewUpdateKubernetesEfficiencyReportParamsWithContext added in v0.0.41

func NewUpdateKubernetesEfficiencyReportParamsWithContext(ctx context.Context) *UpdateKubernetesEfficiencyReportParams

NewUpdateKubernetesEfficiencyReportParamsWithContext creates a new UpdateKubernetesEfficiencyReportParams object with the ability to set a context for a request.

func NewUpdateKubernetesEfficiencyReportParamsWithHTTPClient added in v0.0.41

func NewUpdateKubernetesEfficiencyReportParamsWithHTTPClient(client *http.Client) *UpdateKubernetesEfficiencyReportParams

NewUpdateKubernetesEfficiencyReportParamsWithHTTPClient creates a new UpdateKubernetesEfficiencyReportParams object with the ability to set a custom HTTPClient for a request.

func NewUpdateKubernetesEfficiencyReportParamsWithTimeout added in v0.0.41

func NewUpdateKubernetesEfficiencyReportParamsWithTimeout(timeout time.Duration) *UpdateKubernetesEfficiencyReportParams

NewUpdateKubernetesEfficiencyReportParamsWithTimeout creates a new UpdateKubernetesEfficiencyReportParams object with the ability to set a timeout on a request.

func (*UpdateKubernetesEfficiencyReportParams) SetContext added in v0.0.41

SetContext adds the context to the update kubernetes efficiency report params

func (*UpdateKubernetesEfficiencyReportParams) SetDefaults added in v0.0.41

func (o *UpdateKubernetesEfficiencyReportParams) SetDefaults()

SetDefaults hydrates default values in the update kubernetes efficiency report params (not the query body).

All values with no default are reset to their zero value.

func (*UpdateKubernetesEfficiencyReportParams) SetHTTPClient added in v0.0.41

func (o *UpdateKubernetesEfficiencyReportParams) SetHTTPClient(client *http.Client)

SetHTTPClient adds the HTTPClient to the update kubernetes efficiency report params

func (*UpdateKubernetesEfficiencyReportParams) SetKubernetesEfficiencyReportToken added in v0.0.41

func (o *UpdateKubernetesEfficiencyReportParams) SetKubernetesEfficiencyReportToken(kubernetesEfficiencyReportToken string)

SetKubernetesEfficiencyReportToken adds the kubernetesEfficiencyReportToken to the update kubernetes efficiency report params

func (*UpdateKubernetesEfficiencyReportParams) SetTimeout added in v0.0.41

func (o *UpdateKubernetesEfficiencyReportParams) SetTimeout(timeout time.Duration)

SetTimeout adds the timeout to the update kubernetes efficiency report params

func (*UpdateKubernetesEfficiencyReportParams) SetUpdateKubernetesEfficiencyReport added in v0.0.41

func (o *UpdateKubernetesEfficiencyReportParams) SetUpdateKubernetesEfficiencyReport(updateKubernetesEfficiencyReport *models.UpdateKubernetesEfficiencyReport)

SetUpdateKubernetesEfficiencyReport adds the updateKubernetesEfficiencyReport to the update kubernetes efficiency report params

func (*UpdateKubernetesEfficiencyReportParams) WithContext added in v0.0.41

WithContext adds the context to the update kubernetes efficiency report params

func (*UpdateKubernetesEfficiencyReportParams) WithDefaults added in v0.0.41

WithDefaults hydrates default values in the update kubernetes efficiency report params (not the query body).

All values with no default are reset to their zero value.

func (*UpdateKubernetesEfficiencyReportParams) WithHTTPClient added in v0.0.41

WithHTTPClient adds the HTTPClient to the update kubernetes efficiency report params

func (*UpdateKubernetesEfficiencyReportParams) WithKubernetesEfficiencyReportToken added in v0.0.41

func (o *UpdateKubernetesEfficiencyReportParams) WithKubernetesEfficiencyReportToken(kubernetesEfficiencyReportToken string) *UpdateKubernetesEfficiencyReportParams

WithKubernetesEfficiencyReportToken adds the kubernetesEfficiencyReportToken to the update kubernetes efficiency report params

func (*UpdateKubernetesEfficiencyReportParams) WithTimeout added in v0.0.41

WithTimeout adds the timeout to the update kubernetes efficiency report params

func (*UpdateKubernetesEfficiencyReportParams) WithUpdateKubernetesEfficiencyReport added in v0.0.41

func (o *UpdateKubernetesEfficiencyReportParams) WithUpdateKubernetesEfficiencyReport(updateKubernetesEfficiencyReport *models.UpdateKubernetesEfficiencyReport) *UpdateKubernetesEfficiencyReportParams

WithUpdateKubernetesEfficiencyReport adds the updateKubernetesEfficiencyReport to the update kubernetes efficiency report params

func (*UpdateKubernetesEfficiencyReportParams) WriteToRequest added in v0.0.41

WriteToRequest writes these params to a swagger request

type UpdateKubernetesEfficiencyReportReader added in v0.0.41

type UpdateKubernetesEfficiencyReportReader struct {
	// contains filtered or unexported fields
}

UpdateKubernetesEfficiencyReportReader is a Reader for the UpdateKubernetesEfficiencyReport structure.

func (*UpdateKubernetesEfficiencyReportReader) ReadResponse added in v0.0.41

func (o *UpdateKubernetesEfficiencyReportReader) ReadResponse(response runtime.ClientResponse, consumer runtime.Consumer) (interface{}, error)

ReadResponse reads a server response into the received o.

type UpdateKubernetesEfficiencyReportUnprocessableEntity added in v0.0.41

type UpdateKubernetesEfficiencyReportUnprocessableEntity struct {
	Payload *models.Errors
}

UpdateKubernetesEfficiencyReportUnprocessableEntity describes a response with status code 422, with default header values.

UnprocessableEntity

func NewUpdateKubernetesEfficiencyReportUnprocessableEntity added in v0.0.41

func NewUpdateKubernetesEfficiencyReportUnprocessableEntity() *UpdateKubernetesEfficiencyReportUnprocessableEntity

NewUpdateKubernetesEfficiencyReportUnprocessableEntity creates a UpdateKubernetesEfficiencyReportUnprocessableEntity with default headers values

func (*UpdateKubernetesEfficiencyReportUnprocessableEntity) Code added in v0.0.41

Code gets the status code for the update kubernetes efficiency report unprocessable entity response

func (*UpdateKubernetesEfficiencyReportUnprocessableEntity) Error added in v0.0.41

func (*UpdateKubernetesEfficiencyReportUnprocessableEntity) GetPayload added in v0.0.41

func (*UpdateKubernetesEfficiencyReportUnprocessableEntity) IsClientError added in v0.0.41

IsClientError returns true when this update kubernetes efficiency report unprocessable entity response has a 4xx status code

func (*UpdateKubernetesEfficiencyReportUnprocessableEntity) IsCode added in v0.0.41

IsCode returns true when this update kubernetes efficiency report unprocessable entity response a status code equal to that given

func (*UpdateKubernetesEfficiencyReportUnprocessableEntity) IsRedirect added in v0.0.41

IsRedirect returns true when this update kubernetes efficiency report unprocessable entity response has a 3xx status code

func (*UpdateKubernetesEfficiencyReportUnprocessableEntity) IsServerError added in v0.0.41

IsServerError returns true when this update kubernetes efficiency report unprocessable entity response has a 5xx status code

func (*UpdateKubernetesEfficiencyReportUnprocessableEntity) IsSuccess added in v0.0.41

IsSuccess returns true when this update kubernetes efficiency report unprocessable entity response has a 2xx status code

func (*UpdateKubernetesEfficiencyReportUnprocessableEntity) String added in v0.0.41

Jump to